@@ -1,12 +1,8 @@
 import datetime
 from eggplant.utils.timezone import utc_timestamp, time_to_seconds
-from eggplant.models import DictModel
 
 def json_model_dict(raw_object, use_float_seconds=True):
-    if isinstance(raw_object, DictModel):
-        result = raw_object.dict()
-    else:
-        result = dict(raw_object)
+    result = dict(raw_object)
 
     # DateTimeField and DateField
     datetime_pairs = [(key, utc_timestamp(value, use_float_seconds=use_float_seconds))
